@@ -53,7 +53,7 @@ void PrintInputProcessing(
     // end
     std::cout << "  if !ismissing(" << juliaName << ")" << std::endl;
     std::cout << "    CLISetParam(\"" << d.name << "\", convert("
-        << GetJuliaType<T>() << ", " << juliaName << "))" << std::endl;
+        << GetJuliaType<T>(d) << ", " << juliaName << "))" << std::endl;
     std::cout << "  end" << std::endl;
   }
 }
@@ -137,8 +137,8 @@ void PrintInputProcessing(
   std::string indent(extraIndent + 2, ' ');
   std::string type = StripType(d.cppType);
   std::cout << indent << functionName << "_internal.CLISetParam" << type
-      << "Ptr(\"" << d.name << "\", convert("
-      << GetJuliaType<typename std::remove_pointer<T>::type>() << ", "
+      << "(\"" << d.name << "\", convert("
+      << GetJuliaType<typename std::remove_pointer<T>::type>(d) << ", "
       << juliaName << "))" << std::endl;
 
   if (!d.required)
@@ -169,7 +169,7 @@ void PrintInputProcessing(
     //
     // CLISetParam("<param_name>", convert(<type>, <paramName>))
     std::cout << "  CLISetParam(\"" << d.name << "\", convert("
-        << GetJuliaType<T>() << ", " << juliaName << "), points_are_rows)"
+        << GetJuliaType<T>(d) << ", " << juliaName << "), points_are_rows)"
         << std::endl;
   }
   else
@@ -181,7 +181,7 @@ void PrintInputProcessing(
     // end
     std::cout << "  if !ismissing(" << juliaName << ")" << std::endl;
     std::cout << "    CLISetParam(\"" << d.name << "\", convert("
-        << GetJuliaType<T>() << ", " << juliaName << "), points_are_rows)"
+        << GetJuliaType<T>(d) << ", " << juliaName << "), points_are_rows)"
         << std::endl;
     std::cout << "  end" << std::endl;
   }
