@@ -32,6 +32,11 @@ std::string GetBindingName(const std::string& language,
     // For Python bindings, the name is unchanged.
     return name;
   }
+  else if (language == "julia")
+  {
+    // For Julia bindings, the name is unchanged.
+    return name;
+  }
   else
   {
     throw std::invalid_argument("Don't know how to compute binding name for "
