@@ -20,6 +20,7 @@
 
 #include <mlpack/bindings/cli/print_doc_functions.hpp>
 #include <mlpack/bindings/python/print_doc_functions.hpp>
+#include <mlpack/bindings/julia/print_doc_functions.hpp>
 
 namespace mlpack {
 namespace bindings {
@@ -39,6 +40,10 @@ inline std::string GetBindingName(const std::string& bindingName)
   {
     return python::GetBindingName(bindingName);
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    return julia::GetBindingName(bindingName);
+  }
   else
   {
     throw std::invalid_argument("PrintValue(): unknown "
@@ -59,6 +64,10 @@ inline std::string PrintLanguage(const std::string& language)
   {
     return "Python";
   }
+  else if (language == "julia")
+  {
+    return "Julia";
+  }
   else
   {
     throw std::invalid_argument("PrintLanguage(): unknown "
@@ -79,6 +88,10 @@ inline std::string PrintImport(const std::string& bindingName)
   {
     return python::PrintImport(bindingName);
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    return julia::PrintImport(bindingName);
+  }
   else
   {
     throw std::invalid_argument("PrintImport(): unknown "
@@ -99,6 +112,10 @@ inline std::string PrintOutputOptionInfo()
   {
     return python::PrintOutputOptionInfo();
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    return julia::PrintOutputOptionInfo();
+  }
   else
   {
     throw std::invalid_argument("PrintOutputOptionInfo(): unknown "
@@ -125,6 +142,8 @@ inline std::string ToUnderscores(const std::string& str)
 {
   std::string ret(str);
   std::replace(ret.begin(), ret.end(), ' ', '_');
+  std::replace(ret.begin(), ret.end(), '{', '_');
+  std::replace(ret.begin(), ret.end(), '}', '_');
   return ret;
 }
 
@@ -318,6 +337,10 @@ inline std::string PrintValue(const T& value, bool quotes)
   {
     result = python::PrintValue(value, quotes);
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    result = julia::PrintValue(value, quotes);
+  }
   else
   {
     throw std::invalid_argument("PrintValue(): unknown "
@@ -353,6 +376,10 @@ inline std::string PrintDefault(const std::string& paramName)
     {
       oss << python::PrintDefault(paramName);
     }
+    else if (BindingInfo::Language() == "julia")
+    {
+      oss << julia::PrintDefault(paramName);
+    }
     else
     {
       throw std::invalid_argument("PrintDefault: unknown "
@@ -377,6 +404,10 @@ inline std::string PrintDataset(const std::string& dataset)
   {
     result = python::PrintDataset(dataset);
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    result = julia::PrintDataset(dataset);
+  }
   else
   {
     throw std::invalid_argument("PrintDataset(): unknown "
@@ -400,6 +431,10 @@ inline std::string PrintModel(const std::string& model)
   {
     result = python::PrintModel(model);
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    result = julia::PrintModel(model);
+  }
   else
   {
     throw std::invalid_argument("PrintModel(): unknown "
@@ -416,23 +451,32 @@ inline std::string PrintModel(const std::string& model)
 template<typename... Args>
 std::string ProgramCall(const std::string& programName, Args... args)
 {
-  std::string s = "```";
+  std::string s;
   if (BindingInfo::Language() == "cli")
   {
-    s += "bash\n";
+    s += "```bash\n";
     s += cli::ProgramCall(programName, args...);
   }
   else if (BindingInfo::Language() == "python")
   {
-    s += "python\n";
+    s += "```python\n";
     s += python::ProgramCall(programName, args...);
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    // Julia's ProgramCall() with a set of arguments will automatically enclose
+    // the text in Markdown code, so we don't need to.
+    s += julia::ProgramCall(programName, args...);
+  }
   else
   {
     throw std::invalid_argument("ProgramCall(): unknown "
         "BindingInfo::Language(): " + BindingInfo::Language() + "!");
   }
-  s += "\n```";
+
+  // Close the Markdown code block, but only if we opened one.
+  if (BindingInfo::Language() != "julia")
+    s += "\n```";
   return s;
 }
 
@@ -458,6 +502,14 @@ inline std::string ProgramCall(const std::string& programName)
       s += ">>> " + import + "\n";
     s += python::ProgramCall(programName);
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    s += "julia\n";
+    std::string import = PrintImport(programName);
+    if (import.size() > 0)
+      s += "julia> " + import + "\n";
+    s += julia::ProgramCall(programName);
+  }
   else
   {
     throw std::invalid_argument("ProgramCall(): unknown "
@@ -487,6 +539,10 @@ inline std::string ParamString(const std::string& paramName)
   {
     s = python::ParamString(paramName);
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    s = julia::ParamString(paramName);
+  }
   else
   {
     throw std::invalid_argument("ParamString(): unknown "
@@ -526,6 +582,10 @@ inline bool IgnoreCheck(const T& t)
   {
     return python::IgnoreCheck(t);
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    return julia::IgnoreCheck(t);
+  }
   else
   {
     throw std::invalid_argument("IgnoreCheck(): unknown "
