@@ -17,6 +17,7 @@
 
 #include <mlpack/bindings/cli/print_type_doc.hpp>
 #include <mlpack/bindings/python/print_type_doc.hpp>
+#include <mlpack/bindings/julia/print_type_doc.hpp>
 
 namespace mlpack {
 namespace bindings {
@@ -37,6 +38,10 @@ std::string PrintTypeDoc(const util::ParamData& data)
   {
     return python::PrintTypeDoc<typename std::remove_pointer<T>::type>(data);
   }
+  else if (BindingInfo::Language() == "julia")
+  {
+    return julia::PrintTypeDoc<typename std::remove_pointer<T>::type>(data);
+  }
   else
   {
     throw std::invalid_argument("PrintTypeDoc(): unknown "
