@@ -28,7 +28,7 @@ BernoulliDistribution<DataType>::BernoulliDistribution() :
 
 template<typename DataType>
 BernoulliDistribution<DataType>::BernoulliDistribution(
-    const DataType&& param,
+    const DataType& param,
     const bool applyLogistic,
     const double eps) :
     logits(param),
@@ -36,7 +36,9 @@ BernoulliDistribution<DataType>::BernoulliDistribution(
     eps(eps)
 {
   if (applyLogistic)
+  {
     LogisticFunction::Fn(logits, probability);
+  }
   else
   {
     probability = arma::mat(logits.memptr(), logits.n_rows,
@@ -58,7 +60,7 @@ DataType BernoulliDistribution<DataType>::Sample() const
 
 template<typename DataType>
 double BernoulliDistribution<DataType>::LogProbability(
-    const DataType&& observation) const
+    const DataType& observation) const
 {
   return arma::accu(arma::log(probability + eps) % observation +
       arma::log(1 - probability + eps) % (1 - observation)) /
@@ -67,7 +69,7 @@ double BernoulliDistribution<DataType>::LogProbability(
 
 template<typename DataType>
 void BernoulliDistribution<DataType>::LogProbBackward(
-    const DataType&& observation, DataType&& output) const
+    const DataType& observation, DataType& output) const
 {
   if (!applyLogistic)
   {
