@@ -30,6 +30,7 @@
 #include <mlpack/methods/ann/layer/layer_types.hpp>
 #include <mlpack/methods/ann/layer/layer.hpp>
 #include <mlpack/methods/ann/init_rules/random_init.hpp>
+#include <mlpack/methods/ann/layer/layer_traits.hpp>
 #include <ensmallen.hpp>
 
 namespace mlpack {
@@ -82,6 +83,35 @@ class FFN
   //! Destructor to release allocated memory.
   ~FFN();
 
+  /**
+   * Check if the optimizer has MaxIterations() parameter, if it does
+   * then check if it's value is less than the number of datapoints
+   * in the dataset.
+   *
+   * @tparam OptimizerType Type of optimizer to use to train the model.
+   * @param optimizer optimizer used in the training process.
+   * @param samples Number of datapoints in the dataset.
+   */
+  template<typename OptimizerType>
+  typename std::enable_if<
+      HasMaxIterations<OptimizerType, size_t&(OptimizerType::*)()>
+      ::value, void>::type
+  WarnMessageMaxIterations(OptimizerType& optimizer, size_t samples) const;
+
+  /**
+   * Check if the optimizer has MaxIterations() parameter, if it
+   * doesn't then simply return from the function.
+   *
+   * @tparam OptimizerType Type of optimizer to use to train the model.
+   * @param optimizer optimizer used in the training process.
+   * @param samples Number of datapoints in the dataset.
+   */
+  template<typename OptimizerType>
+  typename std::enable_if<
+      !HasMaxIterations<OptimizerType, size_t&(OptimizerType::*)()>
+      ::value, void>::type
+  WarnMessageMaxIterations(OptimizerType& optimizer, size_t samples) const;
+
   /**
    * Train the feedforward network on the given input data using the given
    * optimizer.
@@ -153,7 +183,9 @@ class FFN
    * @param predictors Input variables.
    * @param responses Target outputs for input variables.
    */
-  double Evaluate(arma::mat predictors, arma::mat responses);
+  template<typename PredictorsType, typename ResponsesType>
+  double Evaluate(const PredictorsType& predictors,
+                  const ResponsesType& responses);
 
   /**
    * Evaluate the feedforward network with the given parameters. This function
@@ -271,7 +303,9 @@ class FFN
   {
     return network;
   }
-  //! Modify the network model.
+  //! Modify the network model.  Be careful!  If you change the structure of the
+  //! network or parameters for layers, its state may become invalid, so be sure
+  //! to call ResetParameters() afterwards.
   std::vector<LayerTypes<CustomLayers...> >& Model() { return network; }
 
   //! Return the number of separable functions (the number of predictor points).
@@ -311,7 +345,8 @@ class FFN
    * @param inputs The input data.
    * @param results The predicted results.
    */
-  void Forward(arma::mat inputs, arma::mat& results);
+  template<typename PredictorsType, typename ResponsesType>
+  void Forward(const PredictorsType& inputs, ResponsesType& results);
 
   /**
    * Perform a partial forward pass of the data.
@@ -324,8 +359,9 @@ class FFN
    * @param begin The index of the first layer.
    * @param end The index of the last layer.
    */
-  void Forward(arma::mat inputs,
-               arma::mat& results,
+  template<typename PredictorsType, typename ResponsesType>
+  void Forward(const PredictorsType& inputs ,
+               ResponsesType& results,
                const size_t begin,
                const size_t end);
 
@@ -340,7 +376,12 @@ class FFN
    * @param gradients Computed gradients.
    * @return Training error of the current pass.
    */
-  double Backward(arma::mat targets, arma::mat& gradients);
+  template<typename PredictorsType,
+           typename TargetsType,
+           typename GradientsType>
+  double Backward(const PredictorsType& inputs,
+                  const TargetsType& targets,
+                  GradientsType& gradients);
 
  private:
   // Helper functions.
@@ -350,7 +391,8 @@ class FFN
    *
    * @param input Data sequence to compute probabilities for.
    */
-  void Forward(arma::mat&& input);
+  template<typename InputType>
+  void Forward(const InputType& input);
 
   /**
    * Prepare the network for the given data.
@@ -371,7 +413,8 @@ class FFN
    * Iterate through all layer modules and update the the gradient using the
    * layer defined optimizer.
    */
-  void Gradient(arma::mat&& input);
+  template<typename InputType>
+  void Gradient(const InputType& input);
 
   /**
    * Reset the module status by setting the current deterministic parameter
@@ -425,9 +468,6 @@ class FFN
   //! The current error for the backward pass.
   arma::mat error;
 
-  //! THe current input of the forward/backward pass.
-  arma::mat currentInput;
-
   //! Locally-stored delta visitor.
   DeltaVisitor deltaVisitor;
 
@@ -494,7 +534,7 @@ template<typename OutputLayerType,
 struct version<
     mlpack::ann::FFN<OutputLayerType, InitializationRuleType, CustomLayer...>>
 {
-  BOOST_STATIC_CONSTANT(int, value = 1);
+  BOOST_STATIC_CONSTANT(int, value = 2);
 };
 
 } // namespace serialization
