@@ -39,6 +39,7 @@ namespace ann /** Artificial Neural Network. */ {
  *   journal = {CoRR},
  *   volume  = {abs/1207.0580},
  *   year    = {2012},
+ *   url     = {https://arxiv.org/abs/1207.0580}
  * }
  * @endcode
  *
@@ -66,7 +67,7 @@ class Dropout
    * @param output Resulting output activation.
    */
   template<typename eT>
-  void Forward(const arma::Mat<eT>&& input, arma::Mat<eT>&& output);
+  void Forward(const arma::Mat<eT>& input, arma::Mat<eT>& output);
 
   /**
    * Ordinary feed backward pass of the dropout layer.
@@ -76,9 +77,9 @@ class Dropout
    * @param g The calculated gradient.
    */
   template<typename eT>
-  void Backward(const arma::Mat<eT>&& /* input */,
-                arma::Mat<eT>&& gy,
-                arma::Mat<eT>&& g);
+  void Backward(const arma::Mat<eT>& /* input */,
+                const arma::Mat<eT>& gy,
+                arma::Mat<eT>& g);
 
   //! Get the output parameter.
   OutputDataType const& OutputParameter() const { return outputParameter; }
