@@ -52,7 +52,7 @@ template<typename InputDataType, typename OutputDataType,
     typename RegularizerType>
 template<typename eT>
 void LinearNoBias<InputDataType, OutputDataType, RegularizerType>::Forward(
-    const arma::Mat<eT>&& input, arma::Mat<eT>&& output)
+    const arma::Mat<eT>& input, arma::Mat<eT>& output)
 {
   output = weight * input;
 }
@@ -61,7 +61,7 @@ template<typename InputDataType, typename OutputDataType,
     typename RegularizerType>
 template<typename eT>
 void LinearNoBias<InputDataType, OutputDataType, RegularizerType>::Backward(
-    const arma::Mat<eT>&& /* input */, arma::Mat<eT>&& gy, arma::Mat<eT>&& g)
+    const arma::Mat<eT>& /* input */, const arma::Mat<eT>& gy, arma::Mat<eT>& g)
 {
   g = weight.t() * gy;
 }
@@ -70,9 +70,9 @@ template<typename InputDataType, typename OutputDataType,
     typename RegularizerType>
 template<typename eT>
 void LinearNoBias<InputDataType, OutputDataType, RegularizerType>::Gradient(
-    const arma::Mat<eT>&& input,
-    arma::Mat<eT>&& error,
-    arma::Mat<eT>&& gradient)
+    const arma::Mat<eT>& input,
+    const arma::Mat<eT>& error,
+    arma::Mat<eT>& gradient)
 {
   gradient.submat(0, 0, weight.n_elem - 1, 0) = arma::vectorise(
       error * input.t());
