@@ -26,9 +26,9 @@ namespace ann /** Artificial Neural Network. */ {
  * i &=& sigmoid(W \cdot x + W \cdot h + W \cdot c + b) \\
  * f &=& sigmoid(W  \cdot x + W \cdot h + W \cdot c + b) \\
  * z &=& tanh(W \cdot x + W \cdot h + b) \\
- * c &=& f \cdot c + i \cdot z \\
+ * c &=& f \odot c + i \odot z \\
  * o &=& sigmoid(W \cdot x + W \cdot h + W \cdot c + b) \\
- * h &=& o \cdot tanh(c)
+ * h &=& o \odot tanh(c)
  * @f}
  *
  * Note that if an LSTM layer is desired as the first layer of a neural network,
@@ -84,7 +84,7 @@ class LSTM
    * @param output Resulting output activation.
    */
   template<typename InputType, typename OutputType>
-  void Forward(InputType&& input, OutputType&& output);
+  void Forward(const InputType& input, OutputType& output);
 
   /**
    * Ordinary feed-forward pass of a neural network, evaluating the function
@@ -96,9 +96,9 @@ class LSTM
    * @param useCellState Use the cellState passed in the LSTM cell.
    */
   template<typename InputType, typename OutputType>
-  void Forward(InputType&& input,
-               OutputType&& output,
-               OutputType&& cellState,
+  void Forward(const InputType& input,
+               OutputType& output,
+               OutputType& cellState,
                bool useCellState = false);
 
   /**
@@ -111,9 +111,9 @@ class LSTM
    * @param g The calculated gradient.
    */
   template<typename InputType, typename ErrorType, typename GradientType>
-  void Backward(const InputType&& input,
-                ErrorType&& gy,
-                GradientType&& g);
+  void Backward(const InputType& input,
+                const ErrorType& gy,
+                GradientType& g);
 
   /*
    * Reset the layer parameter.
@@ -136,9 +136,9 @@ class LSTM
    * @param gradient The calculated gradient.
    */
   template<typename InputType, typename ErrorType, typename GradientType>
-  void Gradient(InputType&& input,
-                ErrorType&& error,
-                GradientType&& gradient);
+  void Gradient(const InputType& input,
+                const ErrorType& error,
+                GradientType& gradient);
 
   //! Get the maximum number of steps to backpropagate through time (BPTT).
   size_t Rho() const { return rho; }
