@@ -47,7 +47,7 @@ class MultiplyConstant
    * @param output Resulting output activation.
    */
   template<typename InputType, typename OutputType>
-  void Forward(const InputType&& input, OutputType&& output);
+  void Forward(const InputType& input, OutputType& output);
 
   /**
    * Ordinary feed backward pass of a neural network. The backward pass
@@ -58,7 +58,7 @@ class MultiplyConstant
    * @param g The calculated gradient.
    */
   template<typename DataType>
-  void Backward(const DataType&& /* input */, DataType&& gy, DataType&& g);
+  void Backward(const DataType& /* input */, const DataType& gy, DataType& g);
 
   //! Get the output parameter.
   OutputDataType& OutputParameter() const { return outputParameter; }
@@ -70,6 +70,11 @@ class MultiplyConstant
   //! Modify the delta.
   OutputDataType& Delta() { return delta; }
 
+  //! Get the scalar multiplier.
+  double Scalar() const { return scalar; }
+  //! Modify the scalar multiplier.
+  double& Scalar() { return scalar; }
+
   /**
    * Serialize the layer.
    */
