@@ -78,6 +78,15 @@ class Sequential
    */
   Sequential(const bool model = true);
 
+  /**
+   * Create the Sequential object using the specified parameters.
+   *
+   * @param model Expose all the network modules.
+   * @param ownsLayers If true, then this module will delete its layers when
+   *      deallocated.
+   */
+  Sequential(const bool model, const bool ownsLayers);
+
   //! Destroy the Sequential object.
   ~Sequential();
 
@@ -89,7 +98,7 @@ class Sequential
    * @param output Resulting output activation.
    */
   template<typename eT>
-  void Forward(arma::Mat<eT>&& input, arma::Mat<eT>&& output);
+  void Forward(const arma::Mat<eT>& input, arma::Mat<eT>& output);
 
   /**
    * Ordinary feed backward pass of a neural network, using 3rd-order tensors as
@@ -101,9 +110,9 @@ class Sequential
    * @param g The calculated gradient.
    */
   template<typename eT>
-  void Backward(const arma::Mat<eT>&& /* input */,
-                arma::Mat<eT>&& gy,
-                arma::Mat<eT>&& g);
+  void Backward(const arma::Mat<eT>& /* input */,
+                const arma::Mat<eT>& gy,
+                arma::Mat<eT>& g);
 
   /*
    * Calculate the gradient using the output delta and the input activation.
@@ -113,9 +122,9 @@ class Sequential
    * @param gradient The calculated gradient.
    */
   template<typename eT>
-  void Gradient(arma::Mat<eT>&& input,
-                arma::Mat<eT>&& error,
-                arma::Mat<eT>&& /* gradient */);
+  void Gradient(const arma::Mat<eT>& input,
+                const arma::Mat<eT>& error,
+                arma::Mat<eT>& /* gradient */);
 
   /*
    * Add a new module to the model.
@@ -132,11 +141,6 @@ class Sequential
    */
   void Add(LayerTypes<CustomLayers...> layer) { network.push_back(layer); }
 
-  /*
-   * Destroy all the modules added to the Sequential object.
-   */
-  void DeleteModules();
-
   //! Return the model modules.
   std::vector<LayerTypes<CustomLayers...> >& Model()
   {
@@ -227,6 +231,9 @@ class Sequential
 
   //! The input height.
   size_t height;
+
+  //! Whether we are responsible for deleting the layers held in this module.
+  bool ownsLayers;
 }; // class Sequential
 
 /*
@@ -243,6 +250,25 @@ using Residual = Sequential<
 } // namespace ann
 } // namespace mlpack
 
+//! Set the serialization version of the Sequential class.
+namespace boost {
+namespace serialization {
+
+template <
+    typename InputDataType,
+    typename OutputDataType,
+    bool Residual,
+    typename... CustomLayers
+>
+struct version<mlpack::ann::Sequential<
+    InputDataType, OutputDataType, Residual, CustomLayers...>>
+{
+  BOOST_STATIC_CONSTANT(int, value = 1);
+};
+
+} // namespace serialization
+} // namespace boost
+
 // Include implementation.
 #include "sequential_impl.hpp"
 
