@@ -27,7 +27,7 @@ class GradientUpdateVisitor : public boost::static_visitor<size_t>
 {
  public:
   //! Update the gradient parameter given the gradient set.
-  GradientUpdateVisitor(arma::mat&& gradient, size_t offset = 0);
+  GradientUpdateVisitor(arma::mat& gradient, size_t offset = 0);
 
   //! Update the gradient parameter.
   template<typename LayerType>
@@ -37,7 +37,7 @@ class GradientUpdateVisitor : public boost::static_visitor<size_t>
 
  private:
   //! The gradient set.
-  arma::mat&& gradient;
+  arma::mat& gradient;
 
   //! The gradient offset.
   size_t offset;
