@@ -19,8 +19,8 @@ namespace mlpack {
 namespace ann {
 
 //! ParametersVisitor visitor class.
-inline ParametersVisitor::ParametersVisitor(arma::mat&& parameters) :
-    parameters(std::move(parameters))
+inline ParametersVisitor::ParametersVisitor(arma::mat& parameters) :
+    parameters(parameters)
 {
   /* Nothing to do here. */
 }
