@@ -100,6 +100,15 @@ PROGRAM_INFO("Collaborative Filtering",
     " - 'average'  -- Average Interpolation Algorithm\n"
     " - 'regression'  -- Regression Interpolation Algorithm\n"
     " - 'similarity'  -- Similarity Interpolation Algorithm\n"
+    "\n\n"
+    "The following ranking normalization algorithms can be specified via" +
+    " the " + PRINT_PARAM_STRING("normalization") + " parameter:"
+    "\n"
+    " - 'none'  -- No Normalization\n"
+    " - 'item_mean'  -- Item Mean Normalization\n"
+    " - 'overall_mean'  -- Overall Mean Normalization\n"
+    " - 'user_mean'  -- User Mean Normalization\n"
+    " - 'z_score'  -- Z-Score Normalization\n"
     "\n"
     "A trained model may be saved to with the " +
     PRINT_PARAM_STRING("output_model") + " output parameter."
@@ -136,6 +145,8 @@ PROGRAM_INFO("Collaborative Filtering",
 PARAM_MATRIX_IN("training", "Input dataset to perform CF on.", "t");
 PARAM_STRING_IN("algorithm", "Algorithm used for matrix factorization.", "a",
     "NMF");
+PARAM_STRING_IN("normalization", "Normalization performed on the ratings.", "z",
+    "none");
 PARAM_INT_IN("neighborhood", "Size of the neighborhood of similar users to "
     "consider for each query user.", "n", 5);
 PARAM_INT_IN("rank", "Rank of decomposed matrices (if 0, a heuristic is used to"
@@ -212,14 +223,14 @@ void ComputeRecommendations(CFModel* cf,
                             const size_t numRecs,
                             arma::Mat<size_t>& recommendations)
 {
-  //  Verifying the Interpolation algorithms
+  // Verify the Interpolation algorithms.
   RequireParamInSet<string>("interpolation", { "average",
       "regression", "similarity" }, true, "unknown interpolation algorithm");
 
-  //  Taking Interpolation Alternatives
+  // Taking Interpolation Alternatives
   const string interpolationAlgorithm = CLI::GetParam<string>("interpolation");
 
-  //  Determining the Interpolation Algorithm
+  // Determining the Interpolation Algorithm
   if (interpolationAlgorithm == "average")
   {
     ComputeRecommendations<NeighborSearchType, AverageInterpolation>
@@ -371,11 +382,29 @@ void PerformAction(arma::mat& dataset,
                    const double minResidue)
 {
   const size_t neighborhood = (size_t) CLI::GetParam<int>("neighborhood");
-  CFModel* c = new CFModel();
-  c->template Train<DecompositionPolicy>(dataset, neighborhood, rank,
-      maxIterations, minResidue, CLI::HasParam("iteration_only_termination"));
 
-  PerformAction(c);
+  // Make sure the normalization strategy is valid.
+  RequireParamInSet<string>("normalization", { "overall_mean", "item_mean",
+      "user_mean", "z_score", "none" }, true, "unknown normalization type");
+
+  CFModel* c = new CFModel();
+
+  const string normalizationType = CLI::GetParam<string>("normalization");
+
+  c->template Train<DecompositionPolicy>(dataset, neighborhood, rank,
+      maxIterations, minResidue, CLI::HasParam("iteration_only_termination"),
+      normalizationType);
+
+  try
+  {
+    PerformAction(c);
+  }
+  catch (std::exception& e)
+  {
+    // Clean the memory before throwing completely.
+    delete c;
+    throw;
+  }
 }
 
 void AssembleFactorizerType(const std::string& algorithm,
