@@ -47,7 +47,9 @@ PROGRAM_INFO("Decision tree",
     " parameter specifies the minimum number of training points that must fall"
     " into each leaf for it to be split.  The " +
     PRINT_PARAM_STRING("minimum_gain_split") + " parameter specifies "
-    "the minimum gain that is needed for the node to split. If " +
+    "the minimum gain that is needed for the node to split.  The " +
+    PRINT_PARAM_STRING("maximum_depth") + " parameter specifies "
+    "the maximum depth of the tree.  If " +
     PRINT_PARAM_STRING("print_training_error") + " is specified, the training "
     "error will be printed."
     "\n\n"
@@ -100,6 +102,8 @@ PARAM_INT_IN("minimum_leaf_size", "Minimum number of points in a leaf.", "n",
     20);
 PARAM_DOUBLE_IN("minimum_gain_split", "Minimum gain for node splitting.", "g",
     1e-7);
+PARAM_INT_IN("maximum_depth", "Maximum depth of the tree (0 means no limit).",
+    "D", 0);
 // This is deprecated and should be removed in mlpack 4.0.0.
 PARAM_FLAG("print_training_error", "Print the training error (deprecated; will "
       "be removed in mlpack 4.0.0).", "e");
@@ -157,6 +161,9 @@ static void mlpackMain()
   RequireParamValue<int>("minimum_leaf_size", [](int x) { return x > 0; }, true,
       "leaf size must be positive");
 
+  RequireParamValue<int>("maximum_depth", [](int x) { return x >= 0; }, true,
+      "maximum depth must not be negative");
+
   RequireParamValue<double>("minimum_gain_split", [](double x)
                          { return (x > 0.0 && x < 1.0); }, true,
                          "gain split must be a fraction in range [0,1]");
@@ -195,6 +202,7 @@ static void mlpackMain()
 
     // Now build the tree.
     const size_t minLeafSize = (size_t) CLI::GetParam<int>("minimum_leaf_size");
+    const size_t maxDepth = (size_t) CLI::GetParam<int>("maximum_depth");
     const double minimumGainSplit =
                            (double) CLI::GetParam<double>("minimum_gain_split");
 
@@ -207,13 +215,14 @@ static void mlpackMain()
           CLI::HasParam("print_training_accuracy"))
       {
         model->tree = DecisionTree<>(trainingSet, model->info, labels,
-            numClasses, std::move(weights), minLeafSize, minimumGainSplit);
+            numClasses, std::move(weights), minLeafSize, minimumGainSplit,
+            maxDepth);
       }
       else
       {
         model->tree = DecisionTree<>(std::move(trainingSet), model->info,
             std::move(labels), numClasses, std::move(weights), minLeafSize,
-            minimumGainSplit);
+            minimumGainSplit, maxDepth);
       }
     }
     else
@@ -221,12 +230,13 @@ static void mlpackMain()
       if (CLI::HasParam("print_training_error"))
       {
         model->tree = DecisionTree<>(trainingSet, model->info, labels,
-            numClasses, minLeafSize, minimumGainSplit);
+            numClasses, minLeafSize, minimumGainSplit, maxDepth);
       }
       else
       {
         model->tree = DecisionTree<>(std::move(trainingSet), model->info,
-            std::move(labels), numClasses, minLeafSize, minimumGainSplit);
+            std::move(labels), numClasses, minLeafSize, minimumGainSplit,
+            maxDepth);
       }
     }
 
