@@ -41,12 +41,12 @@ namespace hmm /** Hidden Markov Models. */ {
  *   double Probability(const DataType& observation) const;
  *
  *   // Estimate the distribution based on the given observations.
- *   void Train(const std::vector<DataType>& observations);
+ *   double Train(const std::vector<DataType>& observations);
  *
  *   // Estimate the distribution based on the given observations, given also
  *   // the probability of each observation coming from this distribution.
- *   void Train(const std::vector<DataType>& observations,
- *              const std::vector<double>& probabilities);
+ *   double Train(const std::vector<DataType>& observations,
+ *                const std::vector<double>& probabilities);
  * };
  * @endcode
  *
@@ -165,8 +165,9 @@ class HMM
    * @endnote
    *
    * @param dataSeq Vector of observation sequences.
+   * @return Log-likelihood of state sequence.
    */
-  void Train(const std::vector<arma::mat>& dataSeq);
+  double Train(const std::vector<arma::mat>& dataSeq);
 
   /**
    * Train the model using the given labeled observations; the transition and
@@ -192,6 +193,30 @@ class HMM
   void Train(const std::vector<arma::mat>& dataSeq,
              const std::vector<arma::Row<size_t> >& stateSeq);
 
+  /**
+   * Estimate the probabilities of each hidden state at each time step for each
+   * given data observation, using the Forward-Backward algorithm.  Each matrix
+   * which is returned has columns equal to the number of data observations, and
+   * rows equal to the number of hidden states in the model.  The log-likelihood
+   * of the most probable sequence is returned.
+   *
+   * @param dataSeq Sequence of observations.
+   * @param stateProb Matrix in which the log probabilities of each state at
+   *    each time interval will be stored.
+   * @param forwardProb Matrix in which the forward log probabilities of each
+   *    state at each time interval will be stored.
+   * @param backwardProb Matrix in which the backward log probabilities of each
+   *    state at each time interval will be stored.
+   * @param scales Vector in which the log of scaling factors at each time
+   *    interval will be stored.
+   * @return Log-likelihood of most likely state sequence.
+   */
+  double LogEstimate(const arma::mat& dataSeq,
+                     arma::mat& stateLogProb,
+                     arma::mat& forwardLogProb,
+                     arma::mat& backwardLogProb,
+                     arma::vec& logScales) const;
+
   /**
    * Estimate the probabilities of each hidden state at each time step for each
    * given data observation, using the Forward-Backward algorithm.  Each matrix
@@ -298,14 +323,22 @@ class HMM
               arma::mat& smoothSeq) const;
 
   //! Return the vector of initial state probabilities.
-  const arma::vec& Initial() const { return initial; }
+  const arma::vec& Initial() const { return initialProxy; }
   //! Modify the vector of initial state probabilities.
-  arma::vec& Initial() { return initial; }
+  arma::vec& Initial()
+  {
+    recalculateInitial = true;
+    return initialProxy;
+  }
 
   //! Return the transition matrix.
-  const arma::mat& Transition() const { return transition; }
+  const arma::mat& Transition() const { return transitionProxy; }
   //! Return a modifiable transition matrix reference.
-  arma::mat& Transition() { return transition; }
+  arma::mat& Transition()
+  {
+    recalculateTransition = true;
+    return transitionProxy;
+  }
 
   //! Return the emission distributions.
   const std::vector<Distribution>& Emission() const { return emission; }
@@ -323,10 +356,19 @@ class HMM
   double& Tolerance() { return tolerance; }
 
   /**
-   * Serialize the object.
+   * Load the object.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int version);
+  void load(Archive& ar, const unsigned int version);
+
+  /**
+   * Save the object.
+   */
+  template<typename Archive>
+  void save(Archive& ar, const unsigned int version) const;
+
+  BOOST_SERIALIZATION_SPLIT_MEMBER();
+
 
  protected:
   // Helper functions.
@@ -341,8 +383,8 @@ class HMM
    * @param forwardProb Matrix in which forward probabilities will be saved.
    */
   void Forward(const arma::mat& dataSeq,
-               arma::vec& scales,
-               arma::mat& forwardProb) const;
+               arma::vec& logScales,
+               arma::mat& forwardLogProb) const;
 
   /**
    * The Backward algorithm (part of the Forward-Backward algorithm).  Computes
@@ -356,24 +398,55 @@ class HMM
    * @param backwardProb Matrix in which backward probabilities will be saved.
    */
   void Backward(const arma::mat& dataSeq,
-                const arma::vec& scales,
-                arma::mat& backwardProb) const;
+                const arma::vec& logScales,
+                arma::mat& backwardLogProb) const;
 
   //! Set of emission probability distributions; one for each state.
   std::vector<Distribution> emission;
 
-  //! Transition probability matrix.
-  arma::mat transition;
+  /**
+   * A proxy variable in linear space for logTransition.
+   * Should be removed in mlpack 4.0.
+   */
+  arma::mat transitionProxy;
+
+  //! Transition probability matrix. No need to be mutable in mlpack 4.0.
+  mutable arma::mat logTransition;
 
  private:
-  //! Initial state probability vector.
-  arma::vec initial;
+  /**
+   * Make sure the variables in log space are in sync
+   * with the linear counter parts.
+   * Should be removed in mlpack 4.0.
+   */
+  void ConvertToLogSpace() const;
+
+  /**
+   * A proxy vriable in linear space for logInitial.
+   * Should be removed in mlpack 4.0.
+   */
+  arma::vec initialProxy;
+
+  //! Initial state probability vector. No need to be mutable in mlpack 4.0.
+  mutable arma::vec logInitial;
 
   //! Dimensionality of observations.
   size_t dimensionality;
 
   //! Tolerance of Baum-Welch algorithm.
   double tolerance;
+
+  /**
+   * Whether or not we need to update the logInitial from initialProxy.
+   * Should be removed in mlpack 4.0.
+   */
+  mutable bool recalculateInitial;
+
+  /**
+   * Whether or not we need to update the logTransition from transitionProxy.
+   * Should be removed in mlpack 4.0.
+   */
+  mutable bool recalculateTransition;
 };
 
 } // namespace hmm
