@@ -248,12 +248,10 @@ static void mlpackMain()
     knn->Tau() = tau;
     knn->Rho() = rho;
 
-    arma::mat referenceSet = std::move(CLI::GetParam<arma::mat>("reference"));
+    Log::Info << "Using reference data from "
+        << CLI::GetPrintableParam<arma::mat>("reference") << "." << endl;
 
-    Log::Info << "Loaded reference data from '"
-        << CLI::GetPrintableParam<arma::mat>("reference") << "' ("
-        << referenceSet.n_rows << " x " << referenceSet.n_cols << ")."
-        << endl;
+    arma::mat referenceSet = std::move(CLI::GetParam<arma::mat>("reference"));
 
     knn->BuildModel(std::move(referenceSet), size_t(lsInt), searchMode,
         epsilon);
@@ -287,10 +285,9 @@ static void mlpackMain()
     arma::mat queryData;
     if (CLI::HasParam("query"))
     {
+      Log::Info << "Using query data from "
+          << CLI::GetPrintableParam<arma::mat>("query") << "." << endl;
       queryData = std::move(CLI::GetParam<arma::mat>("query"));
-      Log::Info << "Loaded query data from '"
-          << CLI::GetPrintableParam<arma::mat>("query") << "' ("
-          << queryData.n_rows << "x" << queryData.n_cols << ")." << endl;
       if (queryData.n_rows != knn->Dataset().n_rows)
       {
         // Clean memory if needed before crashing.
