@@ -314,12 +314,13 @@ class OneStepSarsaWorker
             config.Discount() * targetActionValue;
 
         // Compute the training target for current state.
-        network.Forward(std::get<0>(transition).Encode(), actionValue);
+        arma::mat input = std::get<0>(transition).Encode();
+        network.Forward(input, actionValue);
         actionValue[std::get<1>(transition)] = targetActionValue;
 
         // Compute gradient.
         arma::mat gradients;
-        network.Backward(actionValue, gradients);
+        network.Backward(input, actionValue, gradients);
 
         // Accumulate gradients.
         totalGradients += gradients;
