@@ -22,6 +22,8 @@
 #include <mlpack/methods/softmax_regression/softmax_regression.hpp>
 #include <mlpack/methods/softmax_regression/softmax_regression_impl.hpp>
 #include <mlpack/methods/ann/init_rules/gaussian_init.hpp>
+#include <mlpack/methods/sparse_autoencoder/sparse_autoencoder.hpp>
+
 #include <boost/test/unit_test.hpp>
 
 using namespace mlpack;
@@ -257,4 +259,23 @@ BOOST_AUTO_TEST_CASE(RBMCallbackTest)
   BOOST_REQUIRE_GT(stream.str().length(), 0);
 }
 
+/**
+ * Tests the SparseAutoencoder implementation with
+ * StoreBestCoordinates callback.
+ */
+BOOST_AUTO_TEST_CASE(SparseAutoencodeCallbackTest)
+{
+  // Simple fake dataset.
+  arma::mat data1("0.1 0.2 0.3 0.4 0.5;"
+                  "0.1 0.2 0.3 0.4 0.5;"
+                  "0.1 0.2 0.3 0.4 0.5;"
+                  "0.1 0.2 0.3 0.4 0.5;"
+                  "0.1 0.2 0.3 0.4 0.5");
+
+  ens::L_BFGS optimizer(5, 100);
+  ens::StoreBestCoordinates<arma::mat> cb;
+  mlpack::nn::SparseAutoencoder encoder2(data1, 5, 1, 0, 0, 0 , optimizer, cb);
+  BOOST_REQUIRE_GT(cb.BestObjective(), 0);
+}
+
 BOOST_AUTO_TEST_SUITE_END();
