@@ -397,7 +397,7 @@ BOOST_AUTO_TEST_CASE(FastMKSBaseTest)
   SetInputParam("base", 0.0); // Invalid.
 
   Log::Fatal.ignoreInput = true;
-  BOOST_REQUIRE_THROW(mlpackMain(), std::invalid_argument);
+  BOOST_REQUIRE_THROW(mlpackMain(), std::runtime_error);
   Log::Fatal.ignoreInput = false;
 }
 
@@ -464,6 +464,9 @@ BOOST_AUTO_TEST_CASE(FastMKSKernelTest)
     CLI::GetSingleton().Parameters()["reference"].wasPassed = false;
     CLI::GetSingleton().Parameters()["query"].wasPassed = false;
     CLI::GetSingleton().Parameters()["kernel"].wasPassed = false;
+
+    if (i != nofkerneltypes - 1)
+      bindings::tests::CleanMemory();
   }
 }
 
