@@ -114,7 +114,7 @@ BOOST_AUTO_TEST_CASE(SequenceClassificationBRNNTest)
     BOOST_TEST_CHECKPOINT("Training over");
     arma::cube prediction;
     model.Predict(input, prediction);
-    BOOST_TEST_CHECKPOINT("Predicion over");
+    BOOST_TEST_CHECKPOINT("Prediction over");
 
     size_t error = 0;
     for (size_t i = 0; i < prediction.n_cols; ++i)
@@ -825,7 +825,7 @@ void DistractedSequenceRecallTestNetwork(
         inputTemp = arma::cube(trainInput.at(0, j).memptr(), inputSize, 1,
             trainInput.at(0, j).n_elem / inputSize, false, true);
         labelsTemp = arma::cube(trainLabels.at(0, j).memptr(), outputSize, 1,
-            trainInput.at(0, j).n_elem / outputSize, false, true);
+            trainLabels.at(0, j).n_elem / outputSize, false, true);
 
         model.Train(inputTemp, labelsTemp, opt);
       }
@@ -1413,4 +1413,67 @@ BOOST_AUTO_TEST_CASE(BRNNTrainReturnObjective)
   BOOST_REQUIRE_EQUAL(std::isfinite(objVal), true);
 }
 
+/**
+ * Test that RNN::Train() does not give an error for large rho.
+ */
+BOOST_AUTO_TEST_CASE(LargeRhoValueRnnTest)
+{
+  // Setting rho value greater than sequence length which is 17.
+  const size_t rho = 100;
+  const size_t hiddenSize = 128;
+  const size_t numLetters = 256;
+  using MatType = arma::cube;
+  std::vector<std::string>trainingData = { "THIS IS THE INPUT 0" ,
+                                           "THIS IS THE INPUT 1" ,
+                                           "THIS IS THE INPUT 3"};
+
+
+  RNN<> model(rho);
+  model.Add<IdentityLayer<>>();
+  model.Add<LSTM<>>(numLetters, hiddenSize, rho);
+  model.Add<Dropout<>>(0.1);
+  model.Add<Linear<>>(hiddenSize, numLetters);
+
+  const auto makeInput = [numLetters](const char *line) -> MatType
+  {
+    const auto strLen = strlen(line);
+    // Rows: number of dimensions.
+    // Cols: number of sequences/points.
+    // Slices: number of steps in sequences.
+    MatType result(numLetters, 1, strLen, arma::fill::zeros);
+    for (size_t i = 0; i < strLen; ++i)
+    {
+      result.at(static_cast<arma::uword>(line[i]), 0, i) = 1.0;
+    }
+    return result;
+  };
+
+  const auto makeTarget = [] (const char *line) -> MatType
+  {
+    const auto strLen = strlen(line);
+    // Responses for NegativeLogLikelihood should be
+    // non-one-hot-encoded class IDs (from 1 to num_classes).
+    MatType result(1, 1, strLen, arma::fill::zeros);
+    // The response is the *next* letter in the sequence.
+    for (size_t i = 0; i < strLen - 1; ++i)
+    {
+      result.at(0, 0, i) = static_cast<arma::uword>(line[i + 1]) + 1.0;
+    }
+    // The final response is empty, so we set it to class 0.
+    result.at(0, 0, strLen - 1) = 1.0;
+    return result;
+  };
+
+  std::vector<MatType> inputs(trainingData.size());
+  std::vector<MatType> targets(trainingData.size());
+  for (size_t i = 0; i < trainingData.size(); ++i)
+  {
+    inputs[i] = makeInput(trainingData[i].c_str());
+    targets[i] = makeTarget(trainingData[i].c_str());
+  }
+  ens::SGD<> opt(0.01, 1, 100);
+  double objVal = model.Train(inputs[0], targets[0], opt);
+  BOOST_TEST_CHECKPOINT("Training over");
+}
+
 BOOST_AUTO_TEST_SUITE_END();
